/* $Id$ -*- C++ -*-
 */

#include "contour.h"
#include <cstring>

const double DTOR = M_PI / 180;

enum MODE {m0=0, m1=1, m2=2, mINTERFERENCE=-1, mCOMMON=4, mIGNORE=5};

double distance(const Station& s1, const Station& s2)
{
  double R = 6371; // km
  double dLat = s2._latitude - s1._latitude;
  double dLon = s2._longitude - s1._longitude;

  double a = sin(dLat/2) * sin(dLat/2) +
    cos(s1._latitude) * cos(s2._latitude) * sin(dLon/2) * sin(dLon/2); 
  double c = 2 * atan2(sqrt(a), sqrt(1-a)); 
  return R * c;
}

Angle angle(const Station& s1, const Station& s2)
{
  double dLon = s2._longitude - s1._longitude;

  double y = sin(dLon) * cos(s2._latitude);
  double x = cos(s1._latitude)*sin(s2._latitude)-sin(s1._latitude)*cos(s2._latitude)*cos(dLon);
  return atan2(y, x)/DTOR;
}

void do_it(Station& s1, Station& s2, MODE mode, double increment, bool interfering_is_smaller)
{
  std::string relation;
  switch (mode) {
  case mINTERFERENCE: {
    switch (std::abs(s1._channel - s2._channel)) {
    case 0:  relation = "co-channel";      mode = m0;	   break;
    case 1:  relation = "1st-adjacent";    mode = m1;	   break;
    case 2:  relation = "2nd-adjacent";    mode = m2;	   break;
    case 3:  relation = "3rd-adjacent";    mode = m2;	   break;
    default: relation = "no-interference"; mode = mIGNORE; break;
    };
  } break;
  case m0:      relation = "assume co-channel";      break;
  case m1:      relation = "assume 1st-adjacent";    break;
  case m2:      relation = "assume 2nd-adjacent";    break;
  case mCOMMON: relation = "common";                 break;
  case mIGNORE: relation = "assume no-interference"; break;
  };
  
  double distance = ::distance(s1,s2);
  Angle angle = ::angle(s1, s2);
  
  if (interfering_is_smaller) {
    std::cout << "---";
  }else{
  }

  std::cout << relation << ", distance=" << distance << " bearing from a to b =" << angle << '\n';
  if (mode != mIGNORE) {
    std::cout << "bear-ab\tbear-ba\ta-prot\tb-int\tap-prot\tbp-int\tmargin\n";
    double end = floor(90/increment) * increment;
    if (end >= 90) {
      end -= increment/2;
    }else{
    }
    for (double offset = -end; offset <= end; offset += increment) {
      Angle a1, a2;
      Radial r1, r2;
      double offset1, offset2;
      double protected_raw = 0;
      double interfering_raw = 0;

      if (interfering_is_smaller) {
	offset2 = offset;
	a2 = angle + 180 - offset2;
	r2 = s2[a2];
	switch (mode) {
	case m0:      interfering_raw = r2._i40;  break;
	case m1:      interfering_raw = r2._i54;  break;
	case m2:      interfering_raw = r2._i100; break;
	case mCOMMON: interfering_raw = r2._p60;  break;
	case mINTERFERENCE: 
	case mIGNORE: interfering_raw = 0.;       break;
	};
	double ref = interfering_raw;
	offset1 = atan2(ref * sin(offset * DTOR), distance - ref * cos(offset * DTOR)) / DTOR;
	a1 = angle + offset1;
	r1 = s1[a1];
	protected_raw = r1._p60;
      }else{
	offset1 = offset;
	a1 = angle + offset1;
	r1 = s1[a1];
	protected_raw = r1._p60;
	double ref = protected_raw;
	offset2 = atan2(ref * sin(offset * DTOR), distance - ref * cos(offset * DTOR)) / DTOR;
	a2 = angle + 180 - offset2;
	r2 = s2[a2];
	switch (mode) {
	case m0:      interfering_raw = r2._i40;  break;
	case m1:      interfering_raw = r2._i54;  break;
	case m2:      interfering_raw = r2._i100; break;
	case mCOMMON: interfering_raw = r2._p60;  break;
	case mINTERFERENCE: 
	case mIGNORE: interfering_raw = 0.;       break;
	};
      }
      
      double protected_projected   = protected_raw   * cos(offset1  * DTOR);
      double interfering_projected = interfering_raw * cos(offset2 * DTOR);
      
      std::cout.precision(4);
      std::cout <<         a1
		<< '\t' << a2
		<< '\t' << protected_raw
		<< '\t' << interfering_raw
		<< '\t' << protected_projected
		<< '\t' << interfering_projected
		<< '\t' << distance - (protected_projected + interfering_projected)
		<< "\n";
    }
  }else{
  }
}


int main(int argc, char* argv[])
{
  if (argc <= 1) {
    std::cerr << "no args?\n";
    exit(1);
  }else{
  }
  int file_arg = 1;
  MODE mode = mINTERFERENCE;
  double increment = 5.0;
  bool reverse = false;
  for (;;) {
    int i = file_arg;
    if (strncmp("-r", argv[i], 2)==0) {
      ++file_arg;
      reverse = true;
      std::cout << "reverse\n";
    }else if (strncmp("-i", argv[i], 2)==0) {
      ++file_arg;
      mode = mINTERFERENCE;
      std::cout << "interference\n";
    }else if (strncmp("-c", argv[i], 2)==0) {
      ++file_arg;
      mode = mCOMMON;
      std::cout << "common\n";
    }else if (strncmp("--0", argv[i], 3)==0) {
      ++file_arg;
      mode = m0;
      std::cout << "as if co-channel\n";
    }else if (strncmp("--1", argv[i], 3)==0) {
      ++file_arg;
      mode = m1;
      std::cout << "as if first adjacent\n";
    }else if (strncmp("--2", argv[i], 3)==0) {
      ++file_arg;
      mode = m2;
      std::cout << "as if second adjacent\n";
    }else if (argv[i][0] == '-' && isdigit(argv[i][1])) {
      ++file_arg;
      increment = atof(argv[i]+1);
    }else{
      break;
    }
  }
  
  if (argc <= file_arg) {
    std::cerr << "no file?\n";
    exit(1);
  }
  
  std::cout << argv[file_arg] << "---" << file_arg << '\n';
  std::ifstream f1(argv[file_arg]);
  if (!f1) {
    std::cerr << "can't open file: " << argv[file_arg] << '\n';
    exit(1);
  }
  Station s1(f1);

  for (int ii = file_arg+1; ii < argc; ++ii) {
    if (strcmp(argv[ii],  argv[file_arg]) == 0) {
      // silently skip comparing to itself
      continue;
    }
    std::ifstream f2(argv[ii]);
    if (!f2) {
      std::cerr << "can't open file: " << argv[ii] << ", skipping\n";
      continue;
    }
    Station s2(f2);

    std::cout << "margin for overlap to " << argv[file_arg] << " from " << argv[ii] << '\n';
    do_it(s1, s2, mode, increment, reverse);
    std::cout << '\n';
    
    std::cout << "margin for overlap to " << argv[ii] << " from " << argv[file_arg] << '\n';
    do_it(s2, s1, mode, increment, reverse);
    std::cout << '\n';
  }

  return 0;
}
